@@ -2,7 +2,11 @@ from enum import Enum
 from typing import Union
 
 from duckql.functions.base import BaseFunction
-from typing_extensions import Literal
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 from ..base import BaseType
 from ..properties.property import Property
